@@ -64,15 +64,20 @@ def _correct_classname(cwd, logger):
         config = json.load(config_file)
         print(f"The path is {Path.cwd()}")
         sys.path.insert(0, str(Path.cwd()))
-        cls = __import__(config["insight_file"].replace('.py', ''),
-                         fromlist=[config["insight_class"]])
+        try:
+            cls = __import__(config["insight_file"].replace('.py', ''),
+                             fromlist=[config["insight_class"]])
+        except Exception as e:
+            logger.error(
+                f"Couldn't import {config['insight_class']} from {config['insight_file']}:\n"
+            )
+            raise e
 
         cls = getattr(cls, config['insight_class'])
-        print(f"The Class is: {cls}")
+
         if not issubclass(cls, insight.InsightGenerator):
             logger.error(
-                f"Can't find {config['insight_class']} in {config['insight_name']} (specified in idk.json).\n" +
-                f"{30*' '}Looking for: \"idk.insight.InsightGenerator\" as a subclass of Inight class "
+                f"{config['insight_class']} must be a subclass of \"idk.insight.InsightGenerator\""
             )
             return False
     return True
